@@ -53,23 +53,26 @@ class web:
             return apps
         else:
             return super().__new__(self)
-    def run(self,host="127.0.0.1",port="39001",name='python'):
+    def run(self,host="127.0.0.1",port="39001",name=None):
         """运行开发环境
 
         host: 监听地址
         
         port: 端口
 
-        name: python命令行解释机名字 默认python
+        name: python命令行解释机名字
         """
-        if len(sys.argv)==1 or (len(sys.argv)==2 and sys.argv[1]=='eventlog'):
+        if '--web' in sys.argv or True:
             filename=sys.argv[0][:-3]
             if self.__config.app['app_debug']:
                 arg=sys.argv
-                if len(arg)==2 and arg[1]=='eventlog':
+                if 'eventlog' in arg:
                     self.__impl(host=host,port=port,filename=filename)
                 else:
-                    Events([name,str(filename)+'.py','eventlog'])
+                    if name:
+                        arg.insert(0,name)
+                    arg.append('eventlog')
+                    Events(arg)
             else:
                 self.__impl(
                     host=host,
