@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-import time,hashlib,json,re,os,platform,sys,shutil,zipfile 
+import time,hashlib,json,re,os,platform,sys,shutil,zipfile,requests
 import datetime as core_datetime
 from kcweb import config
 from kcweb.utill.dateutil.relativedelta import relativedelta as core_relativedelta
@@ -413,52 +413,44 @@ class create:
     def installmodular(self):
         "创建模块，如果应用不存，则创建默认应用，如果在您的应用目录下没有模块包，则创建默认模块文件"
         if not os.path.exists(self.appname):
-            os.makedirs(self.appname)
+            # os.makedirs(self.appname)
+            r=requests.get(config.domain['kcwebfile']+"/kcweb/app.zip")
+            f = open("./app.zip", "wb")
+            for chunk in r.iter_content(chunk_size=512):
+                if chunk:
+                    f.write(chunk)
+            f.close()
+            zip.unzip_file("./app.zip","./")
+            os.remove("./app.zip")
+            if not os.path.isfile("./server.py"):
+                if "Windows" in platform.platform():
+                    pythonname="python"
+                else:
+                    pythonname="python3"
+                servertext=('# #gunicorn -b 0.0.0.0:39010 '+self.appname+':app\n'+
+                        'from kcweb import web\n'+
+                        'import '+self.appname+' as application\n'+
+                        'from '+self.appname+'.common import *\n'+
+                        'app=web(__name__,application)\n'+
+                        'if __name__ == "__main__":\n'+
+                        '    #host监听ip port端口 name python解释器名字 (windows一般是python  linux一般是python3)\n'+
+                        '    app.run(host="0.0.0.0",port="39001",name="'+pythonname+'")')
+                f=open("./server.py","w+",encoding='utf-8')
+                f.write(servertext)
+                f.close()
+            return True
         else:
             if not os.path.isfile(self.appname+"/__init__.py") or not os.path.exists(self.appname+"/common"):
                 raise Exception(self.appname+"不是kcweb应用")
-        if not os.path.exists(self.appname+"/common"):
-            os.makedirs(self.appname+"/common")
-            f=open(self.appname+"/common/__init__.py","w+",encoding='utf-8')
-            content=Templates(self.path+"/application/common/__init__.py",appname=self.appname,modular=self.modular)
-            f.write(content)
-            f.close()
-            f=open(self.appname+"/common/autoload.py","w+",encoding='utf-8')
-            content=Templates(self.path+"/application/common/autoload.py",appname=self.appname,modular=self.modular)
-            f.write(content)
-            f.close()
-        if not os.path.exists(self.appname+"/config"):
-            os.makedirs(self.appname+"/config")
-            f=open(self.appname+"/config/__init__.py","w+",encoding='utf-8')
-            content=Templates(self.path+"/application/config/__init__.py",appname=self.appname,modular=self.modular)
-            f.write(content)
-            f.close()
-            f=open(self.appname+"/config/other.py","w+",encoding='utf-8')
-            content=Templates(self.path+"/application/config/other.py",appname=self.appname,modular=self.modular)
-            f.write(content)
-            f.close()
+
         if os.path.exists(self.appname+"/"+self.modular):
             raise Exception(self.appname+"/"+self.modular+"已存在")
         else:
             if os.path.isfile(self.appname+"/"+self.modular+".zip"):#安装打包好的模块
                 zip.unzip_file(self.appname+"/"+self.modular+".zip",self.appname+"/"+self.modular+"/")
                 os.remove(self.appname+"/"+self.modular+".zip")
-            else:
-                os.makedirs(self.appname+"/"+self.modular)#创建模块
-                self.__zxmodular("")
-        
             if os.path.isfile(self.appname+"/__init__.py"):
                 content="\nfrom . import "+self.modular
-            else:
-                #在应用目录下创建初始化文件
-                lists=os.listdir(self.appname)
-                modulars=[]
-                filters=['__init__','__pycache__','common','config','runtime','log']
-                for files in lists:
-                    if not os.path.isfile(self.appname+"/"+files):
-                        if files not in filters:
-                            modulars.append(files)
-                content=Templates(self.path+"/application/__init__.py",appname=self.appname,tuple_modular=modulars)
                 if "Windows" in platform.platform():
                     pythonname="python"
                 else:
@@ -479,26 +471,26 @@ class create:
             f.write(content)
             f.close()
             return True
-    def __zxmodular(self,sourcep):
-        "处理模块文件"
-        path1=self.path+"/application/api"+sourcep
-        path2=self.appname+"/"+self.modular+sourcep
-        lists=os.listdir(path1)
-        for files in lists:
-            if os.path.isfile(path1+"/"+files):
-                if ".py" in files:
-                    content=Templates(path1+"/"+files,appname=self.appname,modular=self.modular)
-                    f=open(path2+"/"+files,"w+",encoding='utf-8')
-                    f.write(content)
-                    f.close()
-                else:
-                    f=open(path1+"/"+files,"r",encoding='utf-8')
-                    content=f.read()
-                    f.close()
-                    f=open(path2+"/"+files,"w+",encoding='utf-8')
-                    f.write(content)
-                    f.close()
-            elif files != '__pycache__':
-                if not os.path.exists(path2+"/"+files):
-                    os.makedirs(path2+"/"+files)
-                self.__zxmodular(sourcep+"/"+files)
\ No newline at end of file
+    # def __zxmodular(self,sourcep):
+    #     "处理模块文件"
+    #     path1=self.path+"/application/api"+sourcep
+    #     path2=self.appname+"/"+self.modular+sourcep
+    #     lists=os.listdir(path1)
+    #     for files in lists:
+    #         if os.path.isfile(path1+"/"+files):
+    #             if ".py" in files:
+    #                 content=Templates(path1+"/"+files,appname=self.appname,modular=self.modular)
+    #                 f=open(path2+"/"+files,"w+",encoding='utf-8')
+    #                 f.write(content)
+    #                 f.close()
+    #             else:
+    #                 f=open(path1+"/"+files,"r",encoding='utf-8')
+    #                 content=f.read()
+    #                 f.close()
+    #                 f=open(path2+"/"+files,"w+",encoding='utf-8')
+    #                 f.write(content)
+    #                 f.close()
+    #         elif files != '__pycache__':
+    #             if not os.path.exists(path2+"/"+files):
+    #                 os.makedirs(path2+"/"+files)
+    #             self.__zxmodular(sourcep+"/"+files)
\ No newline at end of file
